pub fn record_storage_bytes(record: &SpatialRecord) -> RecordsResult<u64>Expand description
Returns the allocated scalar capacity bytes owned by a record.
pub fn record_storage_bytes(record: &SpatialRecord) -> RecordsResult<u64>Returns the allocated scalar capacity bytes owned by a record.