pub struct ChunkIdentity {
pub sequence: u64,
pub point_offset: u64,
}Expand description
Stable location of one chunk in its source stream.
Fields
sequence: u64Zero-based chunk sequence.
point_offset: u64Global point offset of the first point in the chunk.